# Session Log

Started: 2025-04-19T01-16-03

## Instructions
### Global Instructions
Test global

### Project Instructions
Test project

## Messages
- **user**: Hello!
- **assistant**: Hi there!
- **assistant (tool:search)**: Found 2 results

Ended: 2025-04-19T01-16-03
